@@ -242,6 +242,7 @@ void Magick::Options::fillColor(const Magick::Color &fillColor_)
   _drawInfo->fill=fillColor_;
   if (fillColor_ == Magick::Color())
     fillPattern((const MagickCore::Image*) NULL);
+  setOption("fill",fillColor_);
 }
 
 Magick::Color Magick::Options::fillColor(void) const
@@ -303,6 +304,28 @@ std::string Magick::Options::font(void) const
   return(std::string());
 }
 
+void Magick::Options::fontFamily(const std::string &family_)
+{
+  if (family_.length() == 0)
+    {
+      _drawInfo->family=(char *) RelinquishMagickMemory(_drawInfo->font);
+      DestroyString(RemoveImageOption(imageInfo(),"family"));
+    }
+  else
+    {
+      Magick::CloneString(&_drawInfo->family,family_);
+      (void) SetImageOption(imageInfo(),"family",family_.c_str());
+    }
+}
+
+std::string Magick::Options::fontFamily(void) const
+{
+  if (_drawInfo->family)
+    return(std::string(_drawInfo->family));
+  
+  return(std::string());
+}
+
 void Magick::Options::fontPointsize(double pointSize_)
 {
   _imageInfo->pointsize=pointSize_;
@@ -314,6 +337,30 @@ double Magick::Options::fontPointsize(void) const
   return(_imageInfo->pointsize);
 }
 
+void Magick::Options::fontStyle(const StyleType style_)
+{
+  _drawInfo->style=style_;
+  (void) SetImageOption(_imageInfo,"style",CommandOptionToMnemonic(
+    MagickStyleOptions,(ssize_t) style_));
+}
+
+Magick::StyleType Magick::Options::fontStyle(void) const
+{
+  return(_drawInfo->style);
+}
+
+void Magick::Options::fontWeight(const size_t weight_)
+{
+  _drawInfo->weight=weight_;
+  setOption("weight",(double) weight_);
+}
+
+size_t Magick::Options::fontWeight(void) const
+{
+  return(_drawInfo->weight);
+}
+
+
 std::string Magick::Options::format(void) const
 {
   const MagickInfo
@@ -353,14 +400,14 @@ void Magick::Options::magick(const std::string &magick_)
   GetPPException;
   SetImageInfo(_imageInfo,1,exceptionInfo);
   ThrowPPException(_quiet);
-  if (*_imageInfo->magick == '\0')
+  if ( _imageInfo->magick[0] == '\0' )
     throwExceptionExplicit(OptionWarning,"Unrecognized image format",
       magick_.c_str());
 }
 
 std::string Magick::Options::magick(void) const
 {
-  if (*_imageInfo->magick)
+  if ( _imageInfo->magick[0] != '\0' )
     return(std::string(_imageInfo->magick));
  
   return(std::string());
@@ -480,7 +527,7 @@ void Magick::Options::resolutionUnits(Magick::ResolutionType resolutionUnits_)
 
 Magick::ResolutionType Magick::Options::resolutionUnits(void) const
 {
-  return(static_cast<Magick::ResolutionType>(_imageInfo->units));
+  return(_imageInfo->units);
 }
 
 void Magick::Options::samplingFactor(const std::string &samplingFactor_)
@@ -530,6 +577,9 @@ bool Magick::Options::strokeAntiAlias(void) const
 void Magick::Options::strokeColor(const Magick::Color &strokeColor_)
 {
   _drawInfo->stroke=strokeColor_;
+  if (strokeColor_ == Magick::Color())
+    strokePattern((const MagickCore::Image*) NULL);
+  setOption("stroke",strokeColor_);
 }
 
 Magick::Color Magick::Options::strokeColor(void) const
@@ -552,8 +602,12 @@ void Magick::Options::strokeDashArray(const double *strokeDashArray_)
       // Allocate elements
       _drawInfo->dash_pattern=static_cast<double*>(AcquireMagickMemory((x+1)*
         sizeof(double)));
+      if (!_drawInfo->dash_pattern)
+        throwExceptionExplicit(MagickCore::ResourceLimitError,
+          "Unable to allocate dash-pattern memory");
       // Copy elements
       memcpy(_drawInfo->dash_pattern,strokeDashArray_,(x+1)*sizeof(double));
+      _drawInfo->dash_pattern[x]=0.0;
     }
 }
 
@@ -654,6 +708,8 @@ size_t Magick::Options::subRange(void) const
 void Magick::Options::textDirection(DirectionType direction_)
 {
   _drawInfo->direction=direction_;
+  (void) SetImageOption(_imageInfo,"direction",CommandOptionToMnemonic(
+    MagickDirectionOptions,(ssize_t) direction_));
 }
 
 Magick::DirectionType Magick::Options::textDirection() const
@@ -664,6 +720,7 @@ Magick::DirectionType Magick::Options::textDirection() const
 void Magick::Options::textEncoding(const std::string &encoding_)
 {
   CloneString(&_drawInfo->encoding,encoding_.c_str());
+  (void) SetImageOption(imageInfo(),"encoding",encoding_.c_str());
 }
 
 std::string Magick::Options::textEncoding(void) const
@@ -677,6 +734,8 @@ std::string Magick::Options::textEncoding(void) const
 void Magick::Options::textGravity(GravityType gravity_)
 {
   _drawInfo->gravity=gravity_;
+  (void) SetImageOption(_imageInfo,"gravity",CommandOptionToMnemonic(
+    MagickGravityOptions,(ssize_t) gravity_));
 }
 
 Magick::GravityType Magick::Options::textGravity() const
@@ -687,6 +746,7 @@ Magick::GravityType Magick::Options::textGravity() const
 void Magick::Options::textInterlineSpacing(double spacing_)
 {
   _drawInfo->interline_spacing=spacing_;
+  setOption("interline-spacing",spacing_);
 }
 
 double Magick::Options::textInterlineSpacing(void) const
@@ -697,6 +757,7 @@ double Magick::Options::textInterlineSpacing(void) const
 void Magick::Options::textInterwordSpacing(double spacing_)
 {
   _drawInfo->interword_spacing=spacing_;
+  setOption("interword-spacing",spacing_);
 }
 
 double Magick::Options::textInterwordSpacing(void) const
@@ -707,6 +768,7 @@ double Magick::Options::textInterwordSpacing(void) const
 void Magick::Options::textKerning(double kerning_)
 {
   _drawInfo->kerning=kerning_;
+  setOption("kerning",kerning_);
 }
 
 double Magick::Options::textKerning(void) const
@@ -714,6 +776,18 @@ double Magick::Options::textKerning(void) const
   return(_drawInfo->kerning);
 }
 
+void Magick::Options::textUnderColor(const Magick::Color &undercolor_)
+{
+  _drawInfo->undercolor=undercolor_;
+  setOption("undercolor",undercolor_);
+}
+
+Magick::Color Magick::Options::textUnderColor(void) const
+{
+  return(_drawInfo->undercolor);
+}
+
+
 void Magick::Options::tileName(const std::string &tileName_)
 {
   if (tileName_.length() == 0)
@@ -955,3 +1029,21 @@ Magick::Options::Options(const MagickCore::ImageInfo *imageInfo_,
   _quantizeInfo=CloneQuantizeInfo(quantizeInfo_);
   _drawInfo=CloneDrawInfo(imageInfo_,drawInfo_);
 }
+
+void Magick::Options::setOption(const char *name,const Color &value_)
+{
+  std::string
+    option;
+
+  option=value_;
+  (void) SetImageOption(imageInfo(),name,option.c_str());
+}
+
+void Magick::Options::setOption(const char *name,const double value_)
+{
+  char
+    option[MaxTextExtent];
+
+  (void) FormatLocaleString(option,MaxTextExtent,"%.20g",value_);
+  (void) SetImageOption(_imageInfo,name,option);
+}
